#
# spec file for package libXres
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libXRes1
Name:           libXres
Version:        1.2.2
Release:        1.7
Summary:        X Resource extension client library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://xorg.freedesktop.org/
#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXRes
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXRes/
Source:         https://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(resourceproto) >= 1.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8

%description
libXRes provides an X Window System client interface to the Resource
extension to the X protocol. The Resource extension allows for X
clients to see and monitor the X resource usage of various clients
(pixmaps, et al).

%package -n %{lname}
Summary:        X Resource extension client library
Group:          System/Libraries

%description -n %{lname}
libXRes provides an X Window System client interface to the Resource
extension to the X protocol. The Resource extension allows for X
clients to see and monitor the X resource usage of various clients
(pixmaps, et al).

%package devel
Summary:        Development files for the X Resource extension library
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
libXRes provides an X Window System client interface to the Resource
extension to the X protocol. The Resource extension allows for X
clients to see and monitor the X resource usage of various clients
(pixmaps, et al).

This package contains the development headers for the library found
in %{lname}.

%prep
%setup -q

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license COPYING
%{_libdir}/libXRes.so.1*

%files devel
%{_includedir}/X11/*
%{_libdir}/libXRes.so
%{_libdir}/pkgconfig/xres.pc
%{_mandir}/man3/*

%changelog
* Mon Dec  5 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.2
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * Reformat code to X.Org standard style
  * Add .git-blame-ignore-revs to hide whitespace commits from git blame
  * Variable scope reductions
  * Resolve -Wsign-compare warnings from gcc
  * Handle implicit conversion warnings from clang
  * Use calloc instead of malloc to allocate arrays
* Tue Apr  6 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move license to licensedir)
* Wed Mar 31 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.1
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Note ABI of XResQueryClientIds
  * XRes: Use _XRead instead of _XRead32 for reading pid
* Thu Oct 12 2017 sndirsch@suse.com
- added COPYING to %%doc
* Thu Oct 12 2017 sndirsch@suse.com
- mention baselibs.conf as source in specfile
* Wed Oct 11 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.2:
  Version 1.2 of the X-Resource extension (added in xserver 1.13) added some
  new requests allowing inspection of every resource for a client, the bytes
  used per resource, and the PIDs of local clients.
  This is the release for the corresponding client library.
* Sat Jun  1 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.0.7:
  This release primarily provides the fix for the recently announced
  security vulnerability CVE-2013-1988, along with improved compatibility
  with future automake releases.
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.0.6:
  + Janitorial cleanups
  + Build configuration improvements
* Tue Feb  7 2012 jengelh@medozas.de
- Split xorg-x11-libs into separate packages
